@@ -36,20 +36,21 @@
 #'   rendered gradients. Should ideally be 0, but often needs to be around 0.5 or higher.
 #' @param ... other arguments passed on to [`layer()`]. These are
 #'   often aesthetics, used to set an aesthetic to a fixed value, like
-#'   `color = "red"` or `size = 3`. They may also be parameters
+#'   `color = "red"` or `linewidth = 3`. They may also be parameters
 #'   to the paired geom/stat.
 #'
 #' @examples
 #' library(ggplot2)
 #'
 #' # Example for `geom_ridgeline_gradient()`
-#' library(viridis)
-#' d <- data.frame(x = rep(1:5, 3) + c(rep(0, 5), rep(0.3, 5), rep(0.6, 5)),
-#'                 y = c(rep(0, 5), rep(1, 5), rep(3, 5)),
-#'                 height = c(0, 1, 3, 4, 0, 1, 2, 3, 5, 4, 0, 5, 4, 4, 1))
+#' d <- data.frame(
+#'   x = rep(1:5, 3) + c(rep(0, 5), rep(0.3, 5), rep(0.6, 5)),
+#'   y = c(rep(0, 5), rep(1, 5), rep(3, 5)),
+#'   height = c(0, 1, 3, 4, 0, 1, 2, 3, 5, 4, 0, 5, 4, 4, 1)
+#' )
 #' ggplot(d, aes(x, y, height = height, group = y, fill = factor(x+y))) +
 #'   geom_ridgeline_gradient() +
-#'   scale_fill_viridis(discrete = TRUE, direction = -1) +
+#'   scale_fill_viridis_d(direction = -1) +
 #'   theme(legend.position = 'none')
 #' @importFrom ggplot2 layer
 #' @export
@@ -80,19 +81,26 @@ geom_ridgeline_gradient <- function(mapping = NULL, data = NULL, stat = "identit
 GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
   default_aes = aes(
     # ridgeline aesthetics
-    color = "black", fill = "grey70", y = 0, size = 0.5, linetype = 1,
+    color = "black", fill = "grey70", y = 0, linewidth = 0.5, linetype = 1,
     min_height = 0, scale = 1, alpha = NA, datatype = "ridgeline",
 
-    # point aesthetics
-    point_shape = 19, point_color = "black", point_size = 1.5, point_fill = NA,
-    point_alpha = NA, point_stroke = 0.5,
+    # point aesthetics with default
+    point_shape = 19, point_size = 1.5, point_stroke = 0.5,
 
-    # vline aesthetics
-    vline_color = "black", vline_size = 0.5, vline_linetype = 1
+    # point aesthetics, inherited
+    point_colour = NULL, #point_color = NULL,
+    point_fill = NULL, point_alpha = NULL,
+
+    # vline aesthetics, all inherited
+    vline_colour = NULL, #vline_color = NULL,
+    vline_width = NULL, vline_linetype = NULL,
+    vline_size = NULL #<- line size deprecated in ggplot2 3.4.0
   ),
 
   required_aes = c("x", "y", "height"),
 
+  optional_aes = c("point_color", "vline_color", "vline_size", "vline_width"),
+
   extra_params = c("na.rm", "jittered_points"),
 
   setup_data = function(self, data, params) {
@@ -114,8 +122,9 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
     transform(data, ymin = y, ymax = y + scale*height)
   },
 
-  draw_key = function(data, params, size) {
-    lwd <- min(data$size, min(size) / 4)
+  draw_key = function(data, params, linewidth) {
+
+    lwd <- min(data$linewidth, min(linewidth) / 4)
 
     rect_grob <- grid::rectGrob(
       width = grid::unit(1, "npc") - grid::unit(lwd, "mm"),
@@ -128,23 +137,43 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
         linejoin = "mitre"
       ))
 
+    # if vertical lines were drawn then we need to add them to the legend also
+    if (is.null(params$quantile_lines) || !params$quantile_lines) {
+      vlines_grob <- grid::nullGrob()
+    }
+    else {
+      vlines_grob <- grid::segmentsGrob(0.5, 0.1, 0.5, 0.9,
+        gp = grid::gpar(
+          col = data$vline_colour %||% data$vline_color %||% data$colour,
+          lwd = (data$vline_width %||% data$linewidth) * .pt,
+          lty = data$vline_linetype %||% data$linetype,
+          lineend = "butt"
+        )
+      )
+    }
+
+    # if jittered points were drawn then we need to add them to the legend also
     if (is.null(params$jittered_points) || !params$jittered_points) {
-      rect_grob
+      point_grob <- grid::nullGrob()
     }
     else {
-      # if jittered points were drawn then we need to add them to the legend also
       point_grob <- grid::pointsGrob(0.5, 0.5,
         pch = data$point_shape,
         gp = grid::gpar(
-          col = alpha(data$point_color, data$point_alpha),
-          fill = alpha(data$point_fill, data$point_alpha),
+          col = alpha(
+            data$point_colour %||% data$point_color %||% data$colour,
+            data$point_alpha %||% data$alpha
+          ),
+          fill = alpha(
+            data$point_fill %||% data$fill,
+            data$point_alpha %||% data$alpha
+          ),
           fontsize = data$point_size * .pt + data$point_stroke * .stroke / 2,
           lwd = data$point_stroke * .stroke / 2
         )
       )
-
-      grid::grobTree(rect_grob, point_grob)
     }
+    grid::grobTree(rect_grob, vlines_grob, point_grob)
   },
 
 
@@ -192,9 +221,9 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
     data$ymax[data$height < data$min_height] <- NA
 
     # Check that aesthetics are constant
-    aes <- unique(data[c("colour", "size", "linetype")])
+    aes <- unique(data[c("colour", "linewidth", "linetype")])
     if (nrow(aes) > 1) {
-      stop("These aesthetics can not vary along a ridgeline: color, size, linetype")
+      stop("These aesthetics can not vary along a ridgeline: color, linewidth, linetype")
     }
     aes <- as.list(aes)
 
@@ -212,7 +241,11 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
     data <- data[!missing_pos,]
 
     # munching for line
-    positions <- plyr::summarise(data, x = x, y = ymax, id = ids)
+    positions <- with(data, data.frame(
+      x = x,
+      y = ymax,
+      id = ids
+    ))
     munched_line <- ggplot2::coord_munch(coord, positions, panel_params)
 
     # We now break down the polygons further by fill color, since
@@ -240,8 +273,11 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
     }
 
     # munching for polygon
-    positions <- plyr::summarise(data,
-                                 x = c(x, rev(x)), y = c(ymax, rev(ymin)), id = c(ids, rev(ids)))
+    positions <- with(data, data.frame(
+      x = c(x, rev(x)),
+      y = c(ymax, rev(ymin)),
+      id = c(ids, rev(ids))
+    ))
     munched_poly <- ggplot2::coord_munch(coord, positions, panel_params)
 
     # calculate line and area grobs
@@ -263,8 +299,14 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
              coords$x, coords$y,
              pch = coords$point_shape,
              gp = grid::gpar(
-               col = alpha(coords$point_color, coords$point_alpha),
-               fill = alpha(coords$point_fill, coords$point_alpha),
+               col = alpha(
+                 data$point_colour %||% data$point_color %||% data$colour,
+                 data$point_alpha %||% data$alpha
+               ),
+               fill = alpha(
+                 data$point_fill %||% data$fill,
+                 data$point_alpha %||% data$alpha
+               ),
                # Stroke is added around the outside of the point
                fontsize = coords$point_size * .pt + coords$point_stroke * .stroke / 2,
                lwd = coords$point_stroke * .stroke / 2
@@ -277,15 +319,19 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
     if (is.null(data)) {
       return(grid::nullGrob())
     }
+
+    data <- check_vline_size(data)
+    data <- check_size(data)
+
     data$xend <- data$x
     data$y <- data$ymin
     data$yend <- data$ymax
     data$alpha <- NA
 
-    # copy vline aesthetics over
-    data$colour <- data$vline_color
-    data$linetype <- data$vline_linetype
-    data$size <- data$vline_size
+    # copy vline aesthetics over if set
+    data$colour <- data$vline_colour %||% data$vline_color %||% data$colour
+    data$linetype <- data$vline_linetype %||% data$linetype
+    data$linewidth <- data$vline_width %||% data$linewidth
     ggplot2::GeomSegment$draw_panel(data, panel_params, coord)
   },
 
@@ -296,7 +342,7 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
              default.units = "native",
              gp = grid::gpar(
                col = aes$colour,
-               lwd = aes$size * .pt,
+               lwd = aes$linewidth * .pt,
                lty = aes$linetype)
            )
     )
@@ -323,7 +369,7 @@ GeomRidgelineGradient <- ggproto("GeomRidgelineGradient", Geom,
                  default.units = "native",
                  gp = grid::gpar(
                    col = aes$colour,
-                   lwd = aes$size * .pt,
+                   lwd = aes$linewidth * .pt,
                    lty = aes$linetype)
                ))
 
@@ -378,33 +424,46 @@ geom_density_ridges_gradient <- function(mapping = NULL, data = NULL, stat = "de
 #' @examples
 #'
 #' # Example for `geom_density_ridges_gradient()`
-#' ggplot(lincoln_weather, aes(x = `Mean Temperature [F]`, y = `Month`, fill = ..x..)) +
+#' ggplot(lincoln_weather, aes(x = `Mean Temperature [F]`, y = `Month`, fill = stat(x))) +
 #'   geom_density_ridges_gradient(scale = 3, rel_min_height = 0.01) +
-#'   scale_x_continuous(expand = c(0.01, 0)) +
-#'   scale_y_discrete(expand = c(0.01, 0)) +
-#'   scale_fill_viridis(name = "Temp. [F]", option = "C") +
+#'   scale_x_continuous(expand = c(0, 0)) +
+#'   scale_y_discrete(expand = c(0, 0)) +
+#'   scale_fill_viridis_c(name = "Temp. [F]", option = "C") +
+#'   coord_cartesian(clip = "off") +
 #'   labs(title = 'Temperatures in Lincoln NE in 2016') +
-#'   theme_ridges(font_size = 13, grid = TRUE) + theme(axis.title.y = element_blank())
+#'   theme_ridges(font_size = 13, grid = TRUE) +
+#'   theme(axis.title.y = element_blank())
 #' @export
 GeomDensityRidgesGradient <- ggproto("GeomDensityRidgesGradient", GeomRidgelineGradient,
   default_aes = aes(
     # ridgeline aesthetics
-    color = "black", fill = "grey70", size = 0.5, linetype = 1,
+    color = "black", fill = "grey70", linewidth = 0.5, linetype = 1,
     rel_min_height = 0, scale = 1.8, alpha = NA, datatype = "ridgeline",
 
-    # point aesthetics
-    point_shape = 19, point_color = "black", point_size = 1.5, point_fill = NA,
-    point_alpha = NA, point_stroke = 0.5,
+    # point aesthetics with default
+    point_shape = 19, point_size = 1.5, point_stroke = 0.5,
 
-    # vline aesthetics
-    vline_color = "black", vline_size = 0.5, vline_linetype = 1
+    # point aesthetics, inherited
+    point_colour = NULL,# point_color = NULL,
+    point_fill = NULL, point_alpha = NULL,
+
+    # vline aesthetics, all inherited
+    vline_colour = NULL,# vline_color = NULL,
+    vline_width = NULL, vline_linetype = NULL,
+    vline_size = NULL #<- line size deprecated in ggplot2 3.4.0
   ),
 
   required_aes = c("x", "y", "height"),
 
+  optional_aes = c("point_color", "vline_color", "vline_size", "vline_width"),
+
   extra_params = c("na.rm", "panel_scaling", "jittered_points"),
 
   setup_data = function(self, data, params) {
+
+    params <- check_vline_size_param(params)
+    params <- check_size_param(params)
+
     # provide default for panel scaling parameter if it doesn't exist,
     # happens if the geom is called from a stat
     if (is.null(params$panel_scaling)) {
